CleanBarCodeOption enum
Enum representing basic barcode cleaning options.
These options provide basic cleaning functionality for barcodes:
- none: No cleaning is performed
- onlyNumbers: Keeps only numeric characters
- alphaNumericAndAsciiCharOnly: Keeps alphanumeric and ASCII characters
- onlySymbolsAndAsciiChar: Keeps symbols and ASCII characters
Values
- none → const CleanBarCodeOption
-
No cleaning is performed
- onlyNumbers → const CleanBarCodeOption
-
Keeps only numeric characters
- alphaNumericAndAsciiCharOnly → const CleanBarCodeOption
-
Keeps alphanumeric and ASCII characters
- onlySymbolsAndAsciiChar → const CleanBarCodeOption
-
Keeps symbols and ASCII characters
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CleanBarCodeOption> - A constant List of the values in this enum, in order of their declaration.