CustomCleanOption enum

Enum representing custom barcode cleaning options.

These options provide more specific cleaning functionality for barcodes:

Inheritance
Available extensions

Values

onlyNumbers → const CustomCleanOption

Keeps only numeric characters

enCharSmallAndBig → const CustomCleanOption

Keeps English characters (both cases)

enCharSmallAndBigPlusNumbers → const CustomCleanOption

Keeps English characters and numbers

enCharBig → const CustomCleanOption

Keeps only uppercase English characters

enCharBigPlusNumbers → const CustomCleanOption

Keeps uppercase English characters and numbers

enCharSmall → const CustomCleanOption

Keeps only lowercase English characters

enCharSmallPlusNumbers → const CustomCleanOption

Keeps lowercase English characters and numbers

arChar → const CustomCleanOption

Keeps only Arabic characters

arCharPlusNumbers → const CustomCleanOption

Keeps Arabic characters and numbers

arCharAndEnCharBigAndSmall → const CustomCleanOption

Keeps Arabic and English characters

arCharAndEnCharBigAndSmallPlusNumbers → const CustomCleanOption

Keeps Arabic, English characters, and numbers

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CustomCleanOption>
A constant List of the values in this enum, in order of their declaration.